#[non_exhaustive]pub struct RequestDownloadRequest {
pub memory_address: u64,
pub memory_size: u32,
/* private fields */
}Expand description
A request to the server for it to download data from the client
A positive response to this request (RequestDownloadResponse) will happen
after the server takes all necessary actions to receive the data once the server is ready to receive
This is a variable length Request, determined by the address_and_length_format_identifier value
See ISO-14229-1:2020, Table H.1 for format information
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.memory_address: u64Starting address of the server memory. Size is determined by address_and_length_format_identifier
Has a variable number of bytes, max of 5
memory_size: u32Size of the data to be downloaded. Number of bytes sent is determined by address_and_length_format_identifier
Used by the server to validate the data transferred by the [TransferData] service
Has a variable number of bytes, max of 4
Implementations
Sourceimpl RequestDownloadRequest
impl RequestDownloadRequest
Sourcepub fn allowed_nack_codes() -> &'static [NegativeResponseCode]
pub fn allowed_nack_codes() -> &'static [NegativeResponseCode]
Get the allowed NegativeResponseCode variants for this request