pub struct SecurityAccessRequest { /* private fields */ }Expand description
Client request to access a security level
This service supports two primary types of request:
Request Seed
When requesting a seed, the request data represents implementation defined
SecurityAccessDataRecord values.
This data is optional, and its use is implementation defined.
Suppressing a positive response to this request is not supported.
Send Key
When sending a key, the request data represents the key to be sent. After receiving a seed, the client must calculate the corresponding key and send it to the server. The server will then validate the key and respond with a positive or negative response. Successful verification of the key will result in the server unlocking the requested security level. Suppressing a positive response to this request is allowed.
Implementations
Sourceimpl SecurityAccessRequest
impl SecurityAccessRequest
Sourcepub fn suppress_positive_response(&self) -> bool
pub fn suppress_positive_response(&self) -> bool
Getter for whether a positive response should be suppressed
Sourcepub fn access_type(&self) -> SecurityAccessType
pub fn access_type(&self) -> SecurityAccessType
Getter for the requested SecurityAccessType
Sourcepub fn request_data(&self) -> &[u8] ⓘ
pub fn request_data(&self) -> &[u8] ⓘ
Getter for the request data
Sourcepub fn allowed_nack_codes() -> &'static [NegativeResponseCode]
pub fn allowed_nack_codes() -> &'static [NegativeResponseCode]
Get the allowed NegativeResponseCode variants for this request