pub trait DiagnosticDefinition: 'static {
type DID: Identifier + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound;
type DiagnosticPayload: IterableWireFormat + Clone + Debug + Send + Sync + PartialEq + Bound + Bound + 'static;
type RID: RoutineIdentifier + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound;
type RoutinePayload: WireFormat + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound;
}Expand description
A trait that defines the user-defined diagnostic definitions/specifiers for UDS requests and responses.
Used to specify the types of the identifiers and payloads used in UDS requests and responses. It allows for flexibility in defining custom data types while adhering to the UDS protocol.
Required Associated Types
Sourcetype DID: Identifier + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound
type DID: Identifier + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound
UDS Data Identifier
Requests : [ReadDataByIdentifierRequest], [WriteDataByIdentifierRequest], and [ReadDTCInfoRequest]
Responses: [ReadDataByIdentifierResponse], [WriteDataByIdentifierResponse], and [ReadDTCInfoResponse]
Sourcetype DiagnosticPayload: IterableWireFormat + Clone + Debug + Send + Sync + PartialEq + Bound + Bound + 'static
type DiagnosticPayload: IterableWireFormat + Clone + Debug + Send + Sync + PartialEq + Bound + Bound + 'static
Response payload for [ReadDataByIdentifierRequest]
Sourcetype RID: RoutineIdentifier + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound
type RID: RoutineIdentifier + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound
UDS Routine Identifier
This is used to identify the routine to be controlled in a [RoutineControlRequest]
Sourcetype RoutinePayload: WireFormat + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound
type RoutinePayload: WireFormat + Clone + Debug + Send + Sync + PartialEq + 'static + Bound + Bound
Payload for both requests and responses of [RoutineControlRequest] and [RoutineControlResponse]
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".